@@ -1,12 +1,12 @@
 import asyncio
 import contextlib
 import logging
-from collections import namedtuple
 from datetime import datetime, timedelta
-from typing import cast, Optional, Union
+from typing import Optional, Union
 
 import discord
 from redbot.core import commands, i18n, checks, modlog
+from redbot.core.utils import AsyncIter
 from redbot.core.utils.chat_formatting import pagify, humanize_number, bold
 from redbot.core.utils.mod import is_allowed_by_hierarchy, get_audit_reason
 from .abc import MixinMeta
@@ -71,7 +71,7 @@ class KickBanMixin(MixinMeta):
 
         if author == user:
             return _("I cannot let you do that. Self-harm is bad {}").format("\N{PENSIVE FACE}")
-        elif not await is_allowed_by_hierarchy(self.bot, self.settings, guild, author, user):
+        elif not await is_allowed_by_hierarchy(self.bot, self.config, guild, author, user):
             return _(
                 "I cannot let you do that. You are "
                 "not higher than the user in the role "
@@ -82,7 +82,7 @@ class KickBanMixin(MixinMeta):
         elif not (0 <= days <= 7):
             return _("Invalid days. Must be between 0 and 7.")
 
-        toggle = await self.settings.guild(guild).dm_on_kickban()
+        toggle = await self.config.guild(guild).dm_on_kickban()
         if toggle:
             with contextlib.suppress(discord.HTTPException):
                 em = discord.Embed(
@@ -132,28 +132,24 @@ class KickBanMixin(MixinMeta):
         return True
 
     async def check_tempban_expirations(self):
-        member = namedtuple("Member", "id guild")
         while self == self.bot.get_cog("Mod"):
-            for guild in self.bot.guilds:
+            async for guild in AsyncIter(self.bot.guilds, steps=100):
                 if not guild.me.guild_permissions.ban_members:
                     continue
-                try:
-                    banned_users = {b.user.id: b.user for b in (await guild.bans())}
-                except discord.HTTPException:
-                    continue
 
-                async with self.settings.guild(guild).current_tempbans() as guild_tempbans:
+                async with self.config.guild(guild).current_tempbans() as guild_tempbans:
                     for uid in guild_tempbans.copy():
-                        user = banned_users.get(uid, None)
-                        if not user:
-                            continue
                         unban_time = datetime.utcfromtimestamp(
-                            await self.settings.member(member(uid, guild)).banned_until()
+                            await self.config.member_from_ids(guild.id, uid).banned_until()
                         )
                         if datetime.utcnow() > unban_time:  # Time to unban the user
                             queue_entry = (guild.id, uid)
                             try:
-                                await guild.unban(user, reason=_("Tempban finished"))
+                                await guild.unban(
+                                    discord.Object(id=uid), reason=_("Tempban finished")
+                                )
+                            except discord.NotFound:
+                                # user is not banned anymore
                                 guild_tempbans.remove(uid)
                             except discord.HTTPException as e:
                                 # 50013: Missing permissions error code or 403: Forbidden status
@@ -164,6 +160,9 @@ class KickBanMixin(MixinMeta):
                                     )
                                     break  # skip the rest of this guild
                                 log.info(f"Failed to unban member: error code: {e.code}")
+                            else:
+                                # user unbanned successfully
+                                guild_tempbans.remove(uid)
             await asyncio.sleep(60)
 
     @commands.command()
@@ -186,7 +185,7 @@ class KickBanMixin(MixinMeta):
                 )
             )
             return
-        elif not await is_allowed_by_hierarchy(self.bot, self.settings, guild, author, user):
+        elif not await is_allowed_by_hierarchy(self.bot, self.config, guild, author, user):
             await ctx.send(
                 _(
                     "I cannot let you do that. You are "
@@ -199,7 +198,7 @@ class KickBanMixin(MixinMeta):
             await ctx.send(_("I cannot do that due to discord hierarchy rules"))
             return
         audit_reason = get_audit_reason(author, reason)
-        toggle = await self.settings.guild(guild).dm_on_kickban()
+        toggle = await self.config.guild(guild).dm_on_kickban()
         if toggle:
             with contextlib.suppress(discord.HTTPException):
                 em = discord.Embed(
@@ -255,7 +254,7 @@ class KickBanMixin(MixinMeta):
         author = ctx.author
         guild = ctx.guild
         if days is None:
-            days = await self.settings.guild(guild).default_days()
+            days = await self.config.guild(guild).default_days()
 
         result = await self.ban_user(
             user=user, ctx=ctx, days=days, reason=reason, create_modlog_case=True
@@ -309,7 +308,7 @@ class KickBanMixin(MixinMeta):
             return
 
         if days is None:
-            days = await self.settings.guild(guild).default_days()
+            days = await self.config.guild(guild).default_days()
 
         if not (0 <= days <= 7):
             await ctx.send(_("Invalid days. Must be between 0 and 7."))
@@ -409,10 +408,9 @@ class KickBanMixin(MixinMeta):
             invite = ""
 
         queue_entry = (guild.id, user.id)
-        await self.settings.member(user).banned_until.set(unban_time.timestamp())
-        cur_tbans = await self.settings.guild(guild).current_tempbans()
-        cur_tbans.append(user.id)
-        await self.settings.guild(guild).current_tempbans.set(cur_tbans)
+        await self.config.member(user).banned_until.set(unban_time.timestamp())
+        async with self.config.guild(guild).current_tempbans() as current_tempbans:
+            current_tempbans.append(user.id)
 
         with contextlib.suppress(discord.HTTPException):
             # We don't want blocked DMs preventing us from banning
@@ -464,7 +462,7 @@ class KickBanMixin(MixinMeta):
                 )
             )
             return
-        elif not await is_allowed_by_hierarchy(self.bot, self.settings, guild, author, user):
+        elif not await is_allowed_by_hierarchy(self.bot, self.config, guild, author, user):
             await ctx.send(
                 _(
                     "I cannot let you do that. You are "
@@ -540,7 +538,7 @@ class KickBanMixin(MixinMeta):
 
         if await self._voice_perm_check(ctx, user_voice_state, move_members=True) is False:
             return
-        elif not await is_allowed_by_hierarchy(self.bot, self.settings, guild, author, member):
+        elif not await is_allowed_by_hierarchy(self.bot, self.config, guild, author, member):
             await ctx.send(
                 _(
                     "I cannot let you do that. You are "
@@ -620,7 +618,7 @@ class KickBanMixin(MixinMeta):
                 await ctx.send(e)
             await ctx.send(_("Unbanned that user from this server"))
 
-        if await self.settings.guild(guild).reinvite_on_unban():
+        if await self.config.guild(guild).reinvite_on_unban():
             user = ctx.bot.get_user(user_id)
             if not user:
                 await ctx.send(
